@@ -29,6 +29,7 @@
 #include "nmv-i-perspective.h"
 #include "nmv-i-debugger.h"
 #include "nmv-sess-mgr.h"
+#include <sigc++/trackable.h>
 
 NEMIVER_BEGIN_NAMESPACE (nemiver)
 
@@ -47,7 +48,7 @@ public:
 
     virtual void do_init ()  = 0;
 
-    virtual void do_init (IWorkbenchSafePtr &a_workbench)  = 0;
+    virtual void do_init (IWorkbench *a_workbench)  = 0;
 
     virtual const UString& get_perspective_identifier () = 0;
 
@@ -82,6 +83,7 @@ public:
                                   const UString &a_cwd,
                                   const vector<IDebugger::BreakPoint> &) = 0;
 
+    virtual void attach_to_program (unsigned int a_pid) = 0;
     virtual void load_core_file () = 0;
 
     virtual void load_core_file (const UString &a_prog_path,
